/*************************************************************************
* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>
#include <med_outils.h>
#include <hdf5.h>

/*
 * - Nom de la fonction : _MEDdatasetNumEcrire
 * - Description : ecriture d'un dataset tableau numerique
 * - Parametres :
 *     - pere (IN)      : l'ID de l'objet HDF pere ou placer l'attribut
 *     - nom  (IN)      : le nom du dataset
 *     - type (IN)      : type numerique MED { MED_FLOAT64 , MED_INT32 , MED_INT64 }
 *     - interlace (IN) : Choix du type d'entrelacement utilis par l'appelant 
 *                        { MED_FULL_INTERLACE(x1,y1,z1,x2,...)) , MED_NO_INTERLACE(x1,x2,y1,y2,z1,z2) }
 *       - nbdim   (IN) : Dimension des lments
 *       - fixdim  (IN) : MED_ALL ou n de la dimension a enregistrer
 *     - psize     (IN) : Taille du profil  utiliser, MED_NOPF si pas de profil 
 *                        (rfrence les lements, cette taille ne prend pas en compte le nombre de pts de gauss ni la dimension )  
 *       - pflmod  (IN) : Indique comment lire les informations en mmoire { MED_COMPACT, MED_GLOBALE }. 
 *       - modifpfl(IN) : Si psize != MED_NOPF :
 *                         - modifpfl == 1   indique que la taille ou le contenu du profil a chang
 *                         - modifpfl == 0   indique que la taille ou le contenu du profil n'a pas chang
 *       - pfltab  (IN) : Tableau contenant les n dlments  traiter (1....oo)
 *       - ngauss  (IN) : Nombre de points de GAUSS par lment
 *     - size (IN)     : Taille du tableau de valeurs
 *                        (rfrence tous les lements, cette taille  prend en compte le nombre de pts de gauss et la dimension )  
 *     - val  (IN)     : valeurs du tableau
 * - Resultat : 0 en cas de succes, -1 sinon
 */ 

med_err _MEDdatasetNumEcrire(med_idt pere,char *nom, med_type_champ type,
			     med_mode_switch interlace, med_size nbdim, med_size fixdim, 
			     med_size psize, med_mode_profil pflmod, med_int modifpfl, med_size * pfltab,
			     med_int ngauss, med_size *size,  unsigned char *val)
{
  char *  name = "_MEDdatasetNumEcrire";
  int     dummy=0;
  med_err fret=-1;
  med_int majeur, mineur, release;
  MedFuncType func;

  MEDversionLire(pere, &majeur, &mineur, &release);

  func = _MEDversionedApi(name,majeur,mineur,release);
  if ( func != (MedFuncType) NULL )
    func  (dummy, pere, nom,  type,
	    interlace, nbdim, fixdim,
	    psize, pflmod, modifpfl, pfltab,
	    ngauss, size,val, &fret);

  return fret;
}
